.. note::

   This documentation is meant only to describe the details that qts helps make more
   common.  Complete documentation is left to the individual wrappers and the
   underlying C++ Qt library.
